@@ -1,33 +1,13 @@
 package Amazon::DynamoDB::NaHTTP;
-$Amazon::DynamoDB::NaHTTP::VERSION = '0.004';
+
 use strict;
 use warnings;
 
-=head1 NAME
-
-Amazon::DynamoDB::NaHTTP - make requests using L<Net::Async::HTTP>
-
-=head1 VERSION
-
-version 0.004
-
-=head1 DESCRIPTION
-
-Provides a L</request> method which will use L<Net::Async::HTTP> to make
-requests and return a L<Future> containing the result. Used internally by
-L<Amazon::DynamoDB>.
-
-=cut
 
 use Future;
 use Net::Async::HTTP 0.30;
 use IO::Async::Timer::Countdown;
 
-=head2 new
-
-Instantiate.
-
-=cut
 
 sub new { 
     my $class = shift; 
@@ -37,13 +17,6 @@ sub new {
     bless $self, $class;
 }
 
-=head2 request
-
-Issues the request. Expects a single L<HTTP::Request> object,
-and returns a L<Future> which will resolve to the decoded
-response content on success, or the failure reason on failure.
-
-=cut
 
 sub request {
 	my $self = shift;
@@ -60,11 +33,6 @@ sub request {
 	);
 }
 
-=head2 ua
-
-Returns a L<Net::Async::HTTP> instance.
-
-=cut
 
 sub ua {
 	my $self = shift;
@@ -104,6 +72,44 @@ sub loop {
 
 1;
 
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Amazon::DynamoDB::NaHTTP
+
+=head1 VERSION
+
+version 0.05
+
+=head1 DESCRIPTION
+
+Provides a L</request> method which will use L<Net::Async::HTTP> to make
+requests and return a L<Future> containing the result. Used internally by
+L<Amazon::DynamoDB>.
+
+=head2 new
+
+Instantiate.
+
+=head2 request
+
+Issues the request. Expects a single L<HTTP::Request> object,
+and returns a L<Future> which will resolve to the decoded
+response content on success, or the failure reason on failure.
+
+=head2 ua
+
+Returns a L<Net::Async::HTTP> instance.
+
+=head1 NAME
+
+Amazon::DynamoDB::NaHTTP - make requests using L<Net::Async::HTTP>
+
 =head1 AUTHOR
 
 Tom Molesworth <cpan@entitymodel.com>
@@ -113,3 +119,16 @@ Rusty Conover <rusty@luckydinosaur.com>
 
 Copyright Tom Molesworth 2012-2013. Licensed under the same terms as Perl itself.
 Copyright 2014 Lucky Dinosaur LLC.
+
+=head1 AUTHOR
+
+Rusty Conover <rusty@luckydinosaur.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2014 by Rusty Conover.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
